# [Code of Conduct](https://www.contributor-covenant.org/version/2/1/code_of_conduct/)

Please send your complaints and feedback to [xpra@xpra.org](mailto:xpra@xpra.org).

# TLDR

Please be nice and respectful.

# Specific Notes
Here are some recurrent issues that are somewhat specific to this project:
* the [bug reporting guidelines](https://github.com/Xpra-org/xpra/wiki/Reporting-Bugs) should be understood, incomplete reports cost a lot of time and may end up being ignored altogeter
* you may feel that your issue is critical and is wrongly being ignored, but unless you are actively [sponsoring](https://github.com/Xpra-org/xpra/blob/master/docs/SPONSORS.md) the project, there are going to be more pressing issues
* in the long run, almost all project contributions end up taking more time in integration, testing, packaging and maintenance than they took to submit, please be thorough
